..
    DO NOT EDIT
    This file is automatically generated with copier using https://codeberg.org/slidge/legacy-module-template

==========
For admins
==========

If you are the administrator of an XMPP server and want to set up matridge,
this part of the documentation is made for you.

.. toctree::

  install
  config
